@@ -1,21 +1,21 @@
 
-data.check <- function(x,name){
+data.check <- function(x,name,verbose=TRUE){
   
   test = FALSE
   
   if(is.data.frame(x)){
     if(!is.null(dim(x))){
-      cat('\nConverting data frame \'',name,'\' to matrix.\n',sep="")
+      if(verbose){cat('\nConverting data frame \'',name,'\' to matrix.\n',sep="")}
       x = as.matrix(x)
     } else {
-      cat('\nConverting data frame',name,'to vector.\n')
+      if(verbose){cat('\nConverting data frame',name,'to vector.\n')}
       x = as.vector(x)}
   }
   
   
   if (is.numeric(x)&&is.matrix(x)){
     if(1%in%dim(x)){
-      cat('\nConverting 1-column matrix \'',name,'\' to vector\n',sep="")
+      if(verbose){cat('\nConverting 1-column matrix \'',name,'\' to vector\n',sep="")}
       x = as.vector(x)
     }
     test = TRUE
